==> haskell-hls-hlint-plugin-2.0.0.0-76-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-hls-hlint-plugin.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 hls-hlint-plugin
version:              2.0.0.0
visibility:           public
id:                   hls-hlint-plugin-2.0.0.0-KnE7WHImXAxJeSc1G2L5GR
key:                  hls-hlint-plugin-2.0.0.0-KnE7WHImXAxJeSc1G2L5GR
license:              Apache-2.0
copyright:            The Haskell IDE Team
maintainer:           atreyu.bbb@gmail.com
author:               The Haskell IDE Team
synopsis:             Hlint integration plugin with Haskell Language Server
description:
    Please see the README on GitHub at <https://github.com/haskell/haskell-language-server#readme>

category:             Development
abi:                  1aa0a6c37115c2b22a08f19528a5f0d7
exposed:              True
exposed-modules:      Ide.Plugin.Hlint
import-dirs:          /usr/lib/ghc-9.4.8/site-local/hls-hlint-plugin-2.0.0.0
library-dirs:         /usr/lib/ghc-9.4.8/site-local/hls-hlint-plugin-2.0.0.0
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/hls-hlint-plugin-2.0.0.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-hls-hlint-plugin
hs-libraries:         HShls-hlint-plugin-2.0.0.0-KnE7WHImXAxJeSc1G2L5GR
depends:
    Diff-0.4.1-LlG9CqI0BWmDdGO3rVr0iN
    aeson-2.1.2.1-H9spCVKCz3aBZuysSTfrjv
    apply-refact-0.13.0.0-1K74dkrRBii4VMHixiGVRm base-4.17.2.1
    binary-0.8.9.1 bytestring-0.11.5.3 containers-0.6.7
    data-default-0.7.1.1-HuI8bY4bNR4F11jcRg6vOi deepseq-1.4.8.0
    directory-1.3.7.1 extra-1.7.16-G4xNEo2ejjd3lhwl24aWT4
    filepath-1.4.2.2 ghc-9.4.8 ghc-boot-9.4.8
    ghc-exactprint-1.6.1-Fc7v2otRLFp1Ppopag9mZz
    ghc-lib-parser-ex-9.4.0.0-EzokEiK63TG8xTYS3mth89
    ghcide-2.0.0.0-E6Dx7kYreUM4H6fPeL8W5M
    hashable-1.4.4.0-Jc2uKL4S7Fl9QLNJZYpfiY
    hlint-3.5-GjLFc6U1Svv2vB1QMwbvTS
    hls-plugin-api-2.0.0.0-JmOIYZDnxdm3H6edCGyJ2C
    lens-5.2.3-GXFWsxB7RRtIGQiKpxuie1
    lsp-1.6.0.0-6NQEAf1e5oTHsOOe8UJvaW
    refact-0.3.0.2-KPJC6T8FqM8EMkV2k8FDeA
    regex-tdfa-1.3.2.4-3uSstSTaLA6FCpVbUR8EKw stm-2.5.1.0
    temporary-1.3-8FAts4F1AmtHqh7aYyLCzN text-2.0.2
    transformers-0.5.6.2
    unordered-containers-0.2.20-L3M6eILO3KM5ipeNJik2xY

haddock-interfaces:
    /usr/share/doc/haskell-hls-hlint-plugin/html/hls-hlint-plugin.haddock

haddock-html:         /usr/share/doc/haskell-hls-hlint-plugin/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-hls-hlint-plugin-2.0.0.0-77-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-hls-hlint-plugin.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 hls-hlint-plugin
version:              2.0.0.0
visibility:           public
id:                   hls-hlint-plugin-2.0.0.0-4jDaEgGB0oe1MuL3BNL9tg
key:                  hls-hlint-plugin-2.0.0.0-4jDaEgGB0oe1MuL3BNL9tg
license:              Apache-2.0
copyright:            The Haskell IDE Team
maintainer:           atreyu.bbb@gmail.com
author:               The Haskell IDE Team
synopsis:             Hlint integration plugin with Haskell Language Server
description:
    Please see the README on GitHub at <https://github.com/haskell/haskell-language-server#readme>

category:             Development
abi:                  5e19fd107d7306b08aa8461250bd432f
exposed:              True
exposed-modules:      Ide.Plugin.Hlint
import-dirs:          /usr/lib/ghc-9.4.8/site-local/hls-hlint-plugin-2.0.0.0
library-dirs:         /usr/lib/ghc-9.4.8/site-local/hls-hlint-plugin-2.0.0.0
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/hls-hlint-plugin-2.0.0.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-hls-hlint-plugin
hs-libraries:         HShls-hlint-plugin-2.0.0.0-4jDaEgGB0oe1MuL3BNL9tg
depends:
    Diff-0.4.1-LlG9CqI0BWmDdGO3rVr0iN
    aeson-2.1.2.1-H9spCVKCz3aBZuysSTfrjv
    apply-refact-0.13.0.0-1K74dkrRBii4VMHixiGVRm base-4.17.2.1
    binary-0.8.9.1 bytestring-0.11.5.3 containers-0.6.7
    data-default-0.7.1.1-HuI8bY4bNR4F11jcRg6vOi deepseq-1.4.8.0
    directory-1.3.7.1 extra-1.7.16-G4xNEo2ejjd3lhwl24aWT4
    filepath-1.4.2.2 ghc-9.4.8 ghc-boot-9.4.8
    ghc-exactprint-1.6.1-Fc7v2otRLFp1Ppopag9mZz
    ghc-lib-parser-ex-9.4.0.0-EzokEiK63TG8xTYS3mth89
    ghcide-2.0.0.0-HQihl3imjPVA86wh1YK3rW
    hashable-1.4.4.0-Jc2uKL4S7Fl9QLNJZYpfiY
    hlint-3.5-GjLFc6U1Svv2vB1QMwbvTS
    hls-plugin-api-2.0.0.0-JmOIYZDnxdm3H6edCGyJ2C
    lens-5.2.3-GXFWsxB7RRtIGQiKpxuie1
    lsp-1.6.0.0-6NQEAf1e5oTHsOOe8UJvaW
    refact-0.3.0.2-KPJC6T8FqM8EMkV2k8FDeA
    regex-tdfa-1.3.2.4-3uSstSTaLA6FCpVbUR8EKw stm-2.5.1.0
    temporary-1.3-8FAts4F1AmtHqh7aYyLCzN text-2.0.2
    transformers-0.5.6.2
    unordered-containers-0.2.20-L3M6eILO3KM5ipeNJik2xY

haddock-interfaces:
    /usr/share/doc/haskell-hls-hlint-plugin/html/hls-hlint-plugin.haddock

haddock-html:         /usr/share/doc/haskell-hls-hlint-plugin/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
